Ports provide extra communication channels to your instances. You can select ports instead of networks or a mix of both.

|  | Name | IP | Admin State | Status |
--- | --- | --- | --- | --- | --- | ---
Select an item from Available items below
{$ $index + 1 $} |  | {$ ctrl.nameOrID(item) $} | {$ ip.ip_address $} on subnet: {$ item.subnet_names[ip.ip_address] $} | {$ item.admin_state | decode:ctrl.portAdminStates $} | {$ item.status | decode:ctrl.portStatuses $} |
ID {$ item.id $} Project ID {$ item.tenant_id $} Network ID {$ item.network_id $} Network {$ item.network_name $} VNIC type {$ item['binding:vnic_type'] | decode:ctrl.vnicTypes $} Host ID {$ item['binding:host_id'] $}

| Name | IP | Admin State | Status |
--- | --- | --- | --- | --- | ---
No available items
| {$ ctrl.nameOrID(item) $} | {$ ip.ip_address $} on subnet: {$ item.subnet_names[ip.ip_address] $} | {$ item.admin_state | decode:ctrl.portAdminStates $} | {$ item.status | decode:ctrl.portStatuses $} |
ID {$ item.id $} Project ID {$ item.tenant_id $} Network ID {$ item.network_id $} Network {$ item.network_name $} VNIC type {$ item['binding:vnic_type'] | decode:ctrl.vnicTypes $} Host ID {$ item['binding:host_id'] $}